/**
 * apeman react package for card components
 * @constructor ApCard
 */

'use strict'

import React, {PropTypes as types} from 'react'
import classnames from 'classnames'
import {ApImage} from 'apeman-react-image'

/** @lends ApCard */
const ApCard = React.createClass({

  // --------------------
  // Specs
  // --------------------

  propTypes: {
    /** Source of image */
    imgSrc: types.string,
    /** Alt text of image */
    imgAlt: types.string,
    /** Scale policy of iamge */
    imageScale: types.string,
    /** Title text */
    title: types.string,
    /** Content text */
    text: types.string
  },

  mixins: [],

  statics: {},

  getInitialState () {
    return {}
  },

  getDefaultProps () {
    return {
      imageScale: 'fit'
    }
  },

  render () {
    const s = this
    let { state, props } = s

    return (
      <div className={ classnames('ap-card', props.className) }
           style={ Object.assign({}, props.style) }>
        <div className="ap-card-column ap-card-column-0">
          { s._renderImage(props.imgSrc, props.imgAlt, props.imageScale) }
        </div>
        <div className="ap-card-column">
          { s._renderTitle(props.title) }
          { s._renderText(props.text) }
          { props.children }
        </div>
      </div>
    )
  },

  // --------------------
  // Lifecycle
  // --------------------
  
  // ------------------
  // Custom
  // ------------------

  // ------------------
  // Private
  // ------------------

  _renderImage (src, alt, scale) {
    if (!src) {
      return null
    }
    return (
      <ApImage className="ap-card-image"
               src={ src }
               alt={ alt }
               scale={ scale }
      />
    )
  },

  _renderTitle (title) {
    if (!title) {
      return null
    }
    return (
      <h3 className="ap-card-title">{ title }</h3>
    )
  },

  _renderText (text) {
    if (!text) {
      return null
    }
    return (
      <p className="ap-card-text">{ text }</p>
    )
  }
})

export default ApCard
